# Anki Cozmo - Python SDK

![Cozmo](docs/source/images/cozmo-sdk-img.jpg)

Learn more about Cozmo: https://anki.com/cozmo

Learn more about the SDK: https://developer.anki.com/

SDK documentation: http://cozmosdk.anki.com/docs/

Forums: https://forums.anki.com/
